==> feed_plugin-0.0.1.tar.gz: lib/repo/feed_repository.dart <==
import 'dart:async';
import 'dart:convert';

import 'package:feed_plugin/models/post_comment_model.dart';
import 'package:feed_plugin/models/post_model.dart';
import 'package:feed_plugin/models/report_model.dart';
import 'package:feed_plugin/models/report_sub_type_model.dart';
import 'package:feed_plugin/models/report_type_model.dart';
import 'package:feed_plugin/models/user_model.dart';
import 'package:feed_plugin/service/http_service.dart';

class FeedRepository {
  final HttpService _httpService;

  FeedRepository(this._httpService) : assert(_httpService != null);

  Future<List<PostModel>> loadPosts() {
    return _httpService.fetchAllPosts().then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> posts = json.decode(data.body);
        List<PostModel> postsList =
            posts.map((i) => PostModel.fromJson(i)).toList();
        return postsList;
      } else {
        return List<PostModel>.from([]);
      }
    });
  }

  Future<PostModel> addPost(user, title, description, type, attachedUrl) {
    return _httpService
        .addPost(
            user: user,
            description: description,
            type: type,
            attachedUrl: attachedUrl,
            title: title)
        .then((data) async {
      if (data.statusCode >= 200 && data.statusCode < 300) {
        List<dynamic> res = json.decode(data.body);
        List<PostModel> postData =
            res.map((i) => PostModel.fromJson(i)).toList();
        return postData[0];
      }
      return null;
    });
  }

  Future<List<ReportTypeModel>> fetchAllReports() {
    return _httpService.fetchAllReports().then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> reports = json.decode(data.body);
        List<ReportTypeModel> reportsTypeList =
            reports.map((i) => ReportTypeModel.fromJson(i)).toList();
        return reportsTypeList;
      } else {
        return List<ReportTypeModel>.from([]);
      }
    });
  }

  Future<List<ReportSubTypeModel>> fetchSubReport(reportTypeId) {
    return _httpService.fetchSubReport(reportTypeId).then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> reports = json.decode(data.body);
        List<ReportSubTypeModel> reportsSubTypeList =
            reports.map((i) => ReportSubTypeModel.fromJson(i)).toList();
        return reportsSubTypeList;
      } else {
        return List<ReportSubTypeModel>.from([]);
      }
    });
  }

  Future<UserModel> fetchUserData(userId) {
    return _httpService.fetchUser(userId).then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> res = json.decode(data.body);
        dynamic userData = res[0];
        UserModel user = UserModel.fromJson(userData);
        return user;
      } else {
        return null;
      }
    });
  }

  Future<ReportModel> addReport(typeId, userId, postId) {
    return _httpService
        .addReport(typeId: typeId, userId: userId, postId: postId)
        .then((data) async {
      if (data.statusCode >= 200 && data.statusCode < 300) {
        var res = json.decode(data.body);
        ReportModel reportData = ReportModel.fromJson(res[0]);
        return reportData;
      }
      return null;
    });
  }

  Future<bool> updatePostReport(postId) {
    return _httpService.updatePostReport(postId: postId).then((data) async {
      if (data.statusCode >= 200) {
        return true;
      }
      return false;
    });
  }

  Future<UserModel> authenticateUser(
      firstName, lastName, about, profileImg, token) {
    return _httpService
        .authenticateUser(
            firstName: firstName,
            lastName: lastName,
            about: about,
            profileImg: profileImg,
            token: token)
        .then((data) async {
      if (data.statusCode >= 200 && data.statusCode < 300) {
        var res = json.decode(data.body);
        UserModel userData = UserModel.fromJson(res);
        return userData;
      }
      return null;
    });
  }

  Future<bool> removeReport(reportId) {
    return _httpService.removeReport(reportId: reportId).then((data) async {
      if (data.statusCode == 200) {
        return true;
      }
      return false;
    });
  }

  Future<bool> removeComment(commentId) {
    return _httpService.removeComment(commentId: commentId).then((data) async {
      if (data.statusCode == 200) {
        return true;
      }
      return false;
    });
  }

  Future<List<ReportModel>> fetchPostReports(postId) {
    return _httpService.fetchReportByPostId(postId).then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> reports = json.decode(data.body);
        List<ReportModel> reportsList =
            reports.map((i) => ReportModel.fromJson(i)).toList();
        return reportsList;
      } else {
        return List<ReportModel>.from([]);
      }
    });
  }

  Future<List<PostCommentModel>> fetchPostComments(postId) async {
    return _httpService.fetchCommentsByPostId(postId).then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> comments = json.decode(data.body);
        List<PostCommentModel> commentsList =
            comments.map((i) => PostCommentModel.fromJson(i)).toList();
        return commentsList;
      } else {
        return List<PostCommentModel>.from([]);
      }
    });
  }

  Future<List<PostModel>> fetchPostsByUserId(id) async {
    return _httpService.fetchPostsByUserId(id).then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> posts = json.decode(data.body);
        List<PostModel> postsList =
            posts.map((i) => PostModel.fromJson(i)).toList();
        return postsList;
      } else {
        return List<PostModel>.from([]);
      }
    });
  }

  Future<List<ReportModel>> fetchFavoritePosts(currentUserId, saveId) async {
    return _httpService
        .fetchFavoritePosts(currentUserId, saveId)
        .then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> posts = json.decode(data.body);
        List<ReportModel> postsList =
            posts.map((i) => ReportModel.fromJson(i)).toList();
        return postsList;
      } else {
        return List<ReportModel>.from([]);
      }
    });
  }

  Future<List<ReportSubTypeModel>> fetchAllSubType() async {
    return _httpService.fetchAllSubType().then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> reports = json.decode(data.body);
        List<ReportSubTypeModel> reportsSubTypeList =
            reports.map((i) => ReportSubTypeModel.fromJson(i)).toList();
        return reportsSubTypeList;
      } else {
        return List<ReportSubTypeModel>.from([]);
      }
    });
  }
}

==> feed_plugin-0.0.50.tar.gz: lib/repo/feed_repository.dart <==
import 'dart:async';
import 'dart:convert';
// import 'dart:io';
// import 'package:dio/dio.dart';
import 'package:feed_plugin/models/post_comment_model.dart';
import 'package:feed_plugin/models/post_model.dart';
import 'package:feed_plugin/models/report_model.dart';
import 'package:feed_plugin/models/report_sub_type_model.dart';
import 'package:feed_plugin/models/report_type_model.dart';
import 'package:feed_plugin/models/user_model.dart';
import 'package:feed_plugin/service/http_service.dart';

class FeedRepository {
  final HttpService _httpService;

  FeedRepository(this._httpService) : assert(_httpService != null);

  Future<List<PostModel>> loadPosts() {
    return _httpService.fetchAllPosts().then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> posts = json.decode(data.body);
        List<PostModel> postsList =
            posts.map((i) => PostModel.fromJson(i)).toList();
        return postsList;
      } else {
        return List<PostModel>.from([]);
      }
    });
  }

  Future<bool> addPost(user, title, description, type, attachedUrl) {
    return _httpService
        .addPost(
            user: user,
            description: description,
            type: type,
            attachedUrl: attachedUrl,
            title: title)
        .then((data) async {
      if (data.statusCode >= 200 && data.statusCode < 300) {
        List<dynamic> res = json.decode(data.body);
        List<PostModel> postData =
            res.map((i) => PostModel.fromJson(i)).toList();
        if (postData[0] != null) return true;

        return false;
      }
      return null;
    });
  }

  Future<List<ReportTypeModel>> fetchAllReports() {
    return _httpService.fetchAllReports().then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> reports = json.decode(data.body);
        List<ReportTypeModel> reportsTypeList =
            reports.map((i) => ReportTypeModel.fromJson(i)).toList();
        return reportsTypeList;
      } else {
        return List<ReportTypeModel>.from([]);
      }
    });
  }

  Future<List<ReportSubTypeModel>> fetchSubReport(reportTypeId) {
    return _httpService.fetchSubReport(reportTypeId).then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> reports = json.decode(data.body);
        List<ReportSubTypeModel> reportsSubTypeList =
            reports.map((i) => ReportSubTypeModel.fromJson(i)).toList();
        return reportsSubTypeList;
      } else {
        return List<ReportSubTypeModel>.from([]);
      }
    });
  }

  Future<UserModel> fetchUserData(userId) {
    return _httpService.fetchUser(userId).then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> res = json.decode(data.body);
        dynamic userData = res[0];
        UserModel user = UserModel.fromJson(userData);
        return user;
      } else {
        return null;
      }
    });
  }

  Future<ReportModel> addReport(typeId, userId, postId) {
    return _httpService
        .addReport(typeId: typeId, userId: userId, postId: postId)
        .then((data) async {
      if (data.statusCode >= 200 && data.statusCode < 300) {
        var res = json.decode(data.body);
        ReportModel reportData = ReportModel.fromJson(res[0]);
        return reportData;
      }
      return null;
    });
  }

  Future<bool> updatePostReport(postId) {
    return _httpService.updatePostReport(postId: postId).then((data) async {
      if (data.statusCode >= 200) {
        return true;
      }
      return false;
    });
  }

  Future<UserModel> authenticateUser(
      firstName, lastName, about, profileImg, token, socialMedia) {
    return _httpService
        .authenticateUser(
      firstName: firstName,
      lastName: lastName,
      about: about,
      profileImg: profileImg,
      token: token,
    )
        .then((data) async {
      if (data.statusCode >= 200 && data.statusCode < 300) {
        var res = json.decode(data.body);
        UserModel userData = UserModel.fromJson(res);
        if (socialMedia != null) {
          await _httpService
              .updateUserMedia(socialMedia: socialMedia, userId: userData.id)
              .then((user) => {
                    if (data.statusCode >= 200 && data.statusCode < 300)
                      {
                        userData = UserModel.fromJson(json.decode(data.body)),
                      }
                    else
                      {userData = null}
                  });
        }
        return userData;
      }
      return null;
    });
  }

  Future<bool> removeReport(reportId) {
    return _httpService.removeReport(reportId: reportId).then((data) async {
      if (data.statusCode == 200) {
        return true;
      }
      return false;
    });
  }

  Future<bool> removeComment(commentId) {
    return _httpService.removeComment(commentId: commentId).then((data) async {
      if (data.statusCode == 200) {
        return true;
      }
      return false;
    });
  }

  Future<List<ReportModel>> fetchPostReports(postId) {
    return _httpService.fetchReportByPostId(postId).then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> reports = json.decode(data.body);
        List<ReportModel> reportsList =
            reports.map((i) => ReportModel.fromJson(i)).toList();
        return reportsList;
      } else {
        return List<ReportModel>.from([]);
      }
    });
  }

  Future<List<PostCommentModel>> fetchPostComments(postId) async {
    return _httpService.fetchCommentsByPostId(postId).then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> comments = json.decode(data.body);
        List<PostCommentModel> commentsList =
            comments.map((i) => PostCommentModel.fromJson(i)).toList();
        return commentsList;
      } else {
        return List<PostCommentModel>.from([]);
      }
    });
  }

  Future<List<PostModel>> fetchPostsByUserId(id) async {
    return _httpService.fetchPostsByUserId(id).then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> posts = json.decode(data.body);
        List<PostModel> postsList =
            posts.map((i) => PostModel.fromJson(i)).toList();
        return postsList;
      } else {
        return List<PostModel>.from([]);
      }
    });
  }

  Future<List<ReportModel>> fetchFavoritePosts(currentUserId, saveId) async {
    return _httpService
        .fetchFavoritePosts(currentUserId, saveId)
        .then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> posts = json.decode(data.body);
        List<ReportModel> postsList =
            posts.map((i) => ReportModel.fromJson(i)).toList();
        return postsList;
      } else {
        return List<ReportModel>.from([]);
      }
    });
  }

  Future<List<ReportSubTypeModel>> fetchAllSubType() async {
    return _httpService.fetchAllSubType().then((data) async {
      if (data.statusCode == 200) {
        List<dynamic> reports = json.decode(data.body);
        List<ReportSubTypeModel> reportsSubTypeList =
            reports.map((i) => ReportSubTypeModel.fromJson(i)).toList();
        return reportsSubTypeList;
      } else {
        return List<ReportSubTypeModel>.from([]);
      }
    });
  }

  Future<bool> removePost(postId) {
    return _httpService.removePost(postId: postId).then((data) async {
      if (data.statusCode == 200) {
        return true;
      }
      return false;
    });
  }

  // Future<List<String>> uploadFile(file) {
  // return _httpService.uploadFile(file: file).then((data) async {
  //   if (data.statusCode == 200) {
  //     List<dynamic> url = json.decode(data.body);
  //     // List<ReportModel> reportsList =
  //     //     reports.map((i) => ReportModel.fromJson(i)).toList();
  //     return url[0];
  //   } else {
  // return null;
  //   }
  // });
  // }

  // Future<Response> sendFile(File file) async {
  //   try {
  //     String url = "https://feed-content.fra1.digitaloceanspaces.com";
  //     Dio dio = new Dio();
  //     var len = file.lengthSync();
  //     // await file.length();
  //     var response = await dio.put(url,
  //         data: file.openRead(),
  //         options: Options(headers: {
  //           Headers.contentLengthHeader: len,
  //         } // set content-length
  //             ));
  //     print("#############################################");
  //     print(response);
  //     return response;
  //   } catch (e) {
  //     print(e);
  //   }
  // }
}
